@@ -1,11 +1,12 @@
 use std::{
     cmp::{Ord, Ordering, PartialOrd},
     fmt,
+    str::FromStr,
 };
 
 pub type BufferPositionIndex = u32;
 
-#[derive(Default, Copy, Clone, PartialEq, Eq)]
+#[derive(Clone, Copy, PartialEq, Eq)]
 pub struct BufferPosition {
     pub line_index: BufferPositionIndex,
     pub column_byte_index: BufferPositionIndex,
@@ -72,38 +73,21 @@ impl BufferPosition {
             range.from
         }
     }
-
-    pub fn parse(s: &str) -> Option<BufferPosition> {
-        #[inline]
-        fn is_non_ascii_digit(c: char) -> bool {
-            !c.is_ascii_digit()
-        }
-
-        let i = s.find(is_non_ascii_digit).unwrap_or(s.len());
-        let (line, s) = s.split_at(i);
-        let line = line.parse::<BufferPositionIndex>().ok()?.saturating_sub(1);
-
-        let mut chars = s.chars();
-        if !matches!(chars.next(), Some(',')) {
-            return Some(BufferPosition::line_col(line, 0));
-        }
-        let s = chars.as_str();
-
-        let i = s.find(is_non_ascii_digit).unwrap_or(s.len());
-        let column = match s[..i].parse::<BufferPositionIndex>() {
-            Ok(n) => n.saturating_sub(1),
-            Err(_) => return Some(BufferPosition::line_col(line, 0)),
-        };
-        Some(BufferPosition::line_col(line, column))
-    }
 }
 
 impl fmt::Debug for BufferPosition {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        f.write_fmt(format_args!(
+        write!(
+            f,
             "BufferPosition(line: {}, col: {})",
-            self.line_index, self.column_byte_index
-        ))
+            self.line_index, self.column_byte_index,
+        )
+    }
+}
+
+impl fmt::Display for BufferPosition {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{},{}", self.line_index, self.column_byte_index)
     }
 }
 
@@ -129,16 +113,36 @@ impl PartialOrd for BufferPosition {
     }
 }
 
-impl fmt::Display for BufferPosition {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        self.line_index.fmt(f)?;
-        f.write_str(",")?;
-        self.column_byte_index.fmt(f)?;
-        Ok(())
+impl FromStr for BufferPosition {
+    type Err = ();
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        fn is_non_ascii_digit(c: char) -> bool {
+            !c.is_ascii_digit()
+        }
+
+        let i = s.find(is_non_ascii_digit).unwrap_or(s.len());
+        let (line, s) = s.split_at(i);
+        let line = match line.parse::<BufferPositionIndex>() {
+            Ok(line) => line.saturating_sub(1),
+            Err(_) => return Err(()),
+        };
+
+        let mut chars = s.chars();
+        if !matches!(chars.next(), Some(',')) {
+            return Ok(BufferPosition::line_col(line, 0));
+        }
+        let s = chars.as_str();
+
+        let i = s.find(is_non_ascii_digit).unwrap_or(s.len());
+        let column = match s[..i].parse::<BufferPositionIndex>() {
+            Ok(n) => n.saturating_sub(1),
+            Err(_) => return Ok(BufferPosition::line_col(line, 0)),
+        };
+        Ok(BufferPosition::line_col(line, column))
     }
 }
 
-#[derive(Default, Copy, Clone, PartialEq, Eq)]
+#[derive(Clone, Copy, PartialEq, Eq)]
 pub struct BufferRange {
     pub from: BufferPosition,
     pub to: BufferPosition,
@@ -162,13 +166,14 @@ impl BufferRange {
 
 impl fmt::Debug for BufferRange {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        f.write_fmt(format_args!(
+        write!(
+            f,
             "BufferRange(line: {}, col: {} => line: {}, col: {})",
             self.from.line_index,
             self.from.column_byte_index,
             self.to.line_index,
             self.to.column_byte_index
-        ))
+        )
     }
 }
 
@@ -246,25 +251,25 @@ mod tests {
 
     #[test]
     fn buffer_position_parsing() {
-        assert_eq!(None, BufferPosition::parse(""));
-        assert_eq!(None, BufferPosition::parse(","));
-        assert_eq!(None, BufferPosition::parse("a,"));
-        assert_eq!(None, BufferPosition::parse(",b"));
-        assert_eq!(None, BufferPosition::parse("a,b"));
+        assert_eq!(Err(()), "".parse::<BufferPosition>());
+        assert_eq!(Err(()), ",".parse::<BufferPosition>());
+        assert_eq!(Err(()), "a,".parse::<BufferPosition>());
+        assert_eq!(Err(()), ",b".parse::<BufferPosition>());
+        assert_eq!(Err(()), "a,b".parse::<BufferPosition>());
 
-        assert_eq!(Some(pos(0, 0)), BufferPosition::parse("0"));
-        assert_eq!(Some(pos(0, 0)), BufferPosition::parse("1"));
-        assert_eq!(Some(pos(1, 0)), BufferPosition::parse("2"));
-        assert_eq!(Some(pos(98, 0)), BufferPosition::parse("99"));
+        assert_eq!(Ok(pos(0, 0)), "0".parse());
+        assert_eq!(Ok(pos(0, 0)), "1".parse());
+        assert_eq!(Ok(pos(1, 0)), "2".parse());
+        assert_eq!(Ok(pos(98, 0)), "99".parse());
 
-        assert_eq!(Some(pos(0, 0)), BufferPosition::parse("0,0"));
-        assert_eq!(Some(pos(0, 0)), BufferPosition::parse("1,1"));
-        assert_eq!(Some(pos(3, 1)), BufferPosition::parse("4,2"));
-        assert_eq!(Some(pos(98, 98)), BufferPosition::parse("99,99"));
+        assert_eq!(Ok(pos(0, 0)), "0,0".parse());
+        assert_eq!(Ok(pos(0, 0)), "1,1".parse());
+        assert_eq!(Ok(pos(3, 1)), "4,2".parse());
+        assert_eq!(Ok(pos(98, 98)), "99,99".parse());
 
-        assert_eq!(Some(pos(3, 0)), BufferPosition::parse("4,"));
-        assert_eq!(Some(pos(3, 0)), BufferPosition::parse("4,x"));
-        assert_eq!(Some(pos(3, 8)), BufferPosition::parse("4,9xx"));
-        assert_eq!(Some(pos(3, 8)), BufferPosition::parse("4,9,xx"));
+        assert_eq!(Ok(pos(3, 0)), "4,".parse());
+        assert_eq!(Ok(pos(3, 0)), "4,x".parse());
+        assert_eq!(Ok(pos(3, 8)), "4,9xx".parse());
+        assert_eq!(Ok(pos(3, 8)), "4,9,xx".parse());
     }
 }
